<?php
/**
 * Auto_Affiliate_Admin Class
 *
 * @since  1.0.0
 * @package Auto Affiliate
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly

if ( ! class_exists( 'Auto_Affiliate_Admin' ) ) :

   class Auto_Affiliate_Admin {

	   /**
	   * @var array
	   */
	   public $pages = array();

       /**
        * @var array
        */
       public $addons = array();

	   /**
	   * Auto_Affiliate_Admin constructor.
	   */
	   public function __construct() {
           $this->includes();

		   // Display admin notices
		   //add_action( 'admin_notices', array( $this, 'add_admin_notice' ) );

           // Init admin pages
           add_action( 'admin_menu', array( $this, 'add_dashboard_page' ) );

           // Init Admin AJAX class
           new Auto_Affiliate_Admin_AJAX();

		   /**
		   * Triggered when Admin is loaded
		   */
		   do_action( 'auto_affiliate_admin_loaded' );
       }

       /**
	   * Include required files
	   *
	   * @since 1.0.0
	   */
       private function includes() {
           // Admin pages
		   require_once AUTO_AFFILIATE_DIR . '/admin/pages/dashboard-page.php';
           require_once AUTO_AFFILIATE_DIR . '/admin/pages/integrations-page.php';
		   require_once AUTO_AFFILIATE_DIR . '/admin/pages/logs-page.php';
		   require_once AUTO_AFFILIATE_DIR . '/admin/pages/settings-page.php';
		   require_once AUTO_AFFILIATE_DIR . '/admin/pages/license-page.php';
		   require_once AUTO_AFFILIATE_DIR . '/admin/pages/addons-page.php';
		   require_once AUTO_AFFILIATE_DIR . '/admin/pages/wizard-page.php';
		   require_once AUTO_AFFILIATE_DIR . '/admin/pages/welcome-page.php';
		   require_once AUTO_AFFILIATE_DIR . '/admin/pages/import-page.php';

		   // Admin AJAX
		   require_once AUTO_AFFILIATE_DIR . '/admin/classes/class-admin-ajax.php';

           // Admin Data
           require_once AUTO_AFFILIATE_DIR . '/admin/classes/class-admin-data.php';

		   // Admin Addons
           require_once AUTO_AFFILIATE_DIR . '/admin/classes/class-admin-addons.php';
	   }

	   /**
	   * Admin notice
	   *
	   * @since 1.0.0
	   */
	  public function add_admin_notice() {
		$license_activated = get_option( 'auto_affiliate_license_activated');
		if ( empty($license_activated) || $license_activated != '102' ) {
			echo '<div class="updated"><p><strong>Auto Affiliate</strong> is ready. Please <a href="'.admin_url( 'admin.php?page=auto-affiliate-license' ).'">Click Here</a> to add your purchase code and activate the plugin.</p></div>';
		}
   	  }

	   /**
	   * Initialize Dashboard page
	   *
	   * @since 1.0.0
	   */
	   public function add_dashboard_page() {
			$title = __( 'Auto Affiliate', Auto_Affiliate::DOMAIN );
			$this->pages['auto_affiliate']           = new Auto_Affiliate_Dashboard_Page( 'auto-affiliate', 'dashboard', $title, $title, false, false );
			$this->pages['auto_affiliate-dashboard'] = new Auto_Affiliate_Dashboard_Page( 'auto-affiliate', 'dashboard', __( 'Auto Affiliate Dashboard', Auto_Affiliate::DOMAIN ), __( 'Dashboard', Auto_Affiliate::DOMAIN ), 'auto-affiliate' );
	   }

	   /**
		* Add Wizard page
		*
		* @since 1.0.0
		*/
		public function add_wizard_page() {
			add_action( 'admin_menu', array( $this, 'init_wizard_page' ) );
		}

		/**
		 * Initialize Wizard page
		 *
		 * @since 1.0.0
		 */
		public function init_wizard_page() {
			$this->pages['auto-affiliate-wizard'] = new Auto_Affiliate_Wizard_Page(
				'auto-affiliate-wizard',
				'wizard',
				__( 'Activation', Auto_Affiliate::DOMAIN ),
				__( 'Activation ⇪', Auto_Affiliate::DOMAIN ),
				'auto-affiliate'
			);
		}

	   /**
		* Add Integrations page
		*
		* @since 1.0.0
		*/
	   public function add_integrations_page() {
		   add_action( 'admin_menu', array( $this, 'init_integrations_page' ) );
	   }

       /**
        * Initialize Integrations page
        *
        * @since 1.0.0
        */
       public function init_integrations_page() {
           $this->pages['auto-affiliate-integrations'] = new Auto_Affiliate_Integrations_Page(
               'auto-affiliate-integrations',
               'integrations',
               __( 'Integrations', Auto_Affiliate::DOMAIN ),
               __( 'Integrations', Auto_Affiliate::DOMAIN ),
               'auto-affiliate'
           );
       }

	   /**
		* Add Logs page
		*
		* @since 1.0.0
		*/
	   public function add_logs_page() {
		   add_action( 'admin_menu', array( $this, 'init_logs_page' ) );
	   }

	   /**
		* Initialize Logs page
		*
		* @since 1.0.0
		*/
	   public function init_logs_page() {
		   $this->pages['auto-affiliate-logs'] = new Auto_Affiliate_Logs_Page(
			   'auto-affiliate-logs',
			   'logs',
			   __( 'Logs', Auto_Affiliate::DOMAIN ),
			   __( 'Logs', Auto_Affiliate::DOMAIN ),
			   'auto-affiliate'
		   );
	   }

	   /**
		* Add settings page
		*
		* @since 1.0.0
		*/
	   public function add_settings_page() {
		   add_action( 'admin_menu', array( $this, 'init_settings_page' ) );
	   }

	   /**
		* Initialize Logs page
		*
		* @since 1.0.0
		*/
	   public function init_settings_page() {
		   $this->pages['auto-affiliate-settings'] = new Auto_Affiliate_Settings_Page(
			   'auto-affiliate-settings',
			   'settings',
			   __( 'Settings', Auto_Affiliate::DOMAIN ),
			   __( 'Settings', Auto_Affiliate::DOMAIN ),
			   'auto-affiliate'
		   );
	   }

	   /**
		* Add license page
		*
		* @since 1.0.0
		*/
		public function add_license_page() {
			add_action( 'admin_menu', array( $this, 'init_license_page' ) );
		}

		/**
		 * Initialize Logs page
		 *
		 * @since 1.0.0
		 */
		public function init_license_page() {
			$this->pages['auto-affiliate-license'] = new Auto_Affiliate_License_Page(
				'auto-affiliate-license',
				'license',
				__( 'License', Auto_Affiliate::DOMAIN ),
				__( 'License', Auto_Affiliate::DOMAIN ),
				'auto-affiliate'
			);
		}

	   /**
		* Add addons page
		*
		* @since 1.0.0
		*/
		public function add_addons_page() {
			add_action( 'admin_menu', array( $this, 'init_addons_page' ) );
		}

		/**
		 * Initialize addons page
		 *
		 * @since 1.0.0
		 */
		public function init_addons_page() {
			$this->pages['auto-affiliate-addons'] = new Auto_Affiliate_Addons_Page(
				'auto-affiliate-addons',
				'addons',
				__( 'Addons', Auto_Affiliate::DOMAIN ),
				__( 'Addons', Auto_Affiliate::DOMAIN ),
				'auto-affiliate'
			);
		}

		/**
		* Add welcome page
		*
		* @since 1.0.0
		*/
		public function add_welcome_page() {
			add_action( 'admin_menu', array( $this, 'init_welcome_page' ) );
		}

		/**
		 * Initialize Logs page
		 *
		 * @since 1.0.0
		 */
		public function init_welcome_page() {
			$this->pages['auto-affiliate-welcome'] = new Auto_Affiliate_Welcome_Page(
				'auto-affiliate-welcome',
				'welcome',
				__( 'Welcome', Auto_Affiliate::DOMAIN ),
				__( 'Welcome', Auto_Affiliate::DOMAIN ),
				'auto-affiliate'
			);
		}

		/**
		* Add import page
		*
		* @since 1.0.0
		*/
		public function add_import_page() {
			add_action( 'admin_menu', array( $this, 'init_import_page' ) );
		}

		/**
		 * Initialize Logs page
		 *
		 * @since 1.0.0
		 */
		public function init_import_page() {
			$this->pages['auto-affiliate-import'] = new Auto_Affiliate_Import_Page(
				'auto-affiliate-import',
				'import',
				__( 'Import / Export', Auto_Affiliate::DOMAIN ),
				__( 'Import / Export', Auto_Affiliate::DOMAIN ),
				'auto-affiliate'
			);
		}


   }

endif;
