(function($){

    "use strict";

    var AutoAffiliateAction = {

        init: function()
        {
            // Document ready.
            $( document ).ready( AutoAffiliateAction._stickyHeader() );
            $( document ).ready( AutoAffiliateAction._loadPopup() );
            $( document ).ready( AutoAffiliateAction._mobileSelect() );
            $( document ).ready( AutoAffiliateAction._rangeSlider() );
            $( document ).ready( AutoAffiliateAction._mainSelect() );
            $( document ).ready( AutoAffiliateAction._postSelect() );
            $( document ).ready( AutoAffiliateAction._typeSelect() );
            $( document ).ready( AutoAffiliateAction._authorSelect() );
            $( document ).ready( AutoAffiliateAction._categorySelect() );
            $( document ).ready( AutoAffiliateAction._sourceSelect() );
            $( document ).ready( AutoAffiliateAction._translatorAPISelector() );



            this._bind();
        },

        /**
         * Binds events for the Auto Affiliate Action.
         *
         * @since 1.0.0
         * @access private
         * @method _bind
         */
        _bind: function()
        {
            $( document ).on('click', '.affiliate-vertical-tab a', AutoAffiliateAction._switchTabs );
            $( document ).on('keyup', '#affiliate-search', AutoAffiliateAction._searchSuggest );
            $( document ).on('click', '.affiliate-keyword-selected', AutoAffiliateAction._selectKeyword );
            $( document ).on('click', '#affiliate-campaign-save', AutoAffiliateAction._saveCampaign );
            $( document ).on('click', '#affiliate-campaign-publish', AutoAffiliateAction._publishCampaign );
            $( document ).on('click', '.affiliate-run-campaign-button', AutoAffiliateAction._runCampaign );
            $( document ).on('click', '.sui-tab-item', AutoAffiliateAction._switchSuiTabs );
            $( document ).on('click', '.source-select-list-container', AutoAffiliateAction._sourceSelectTab );
            $( document ).on('click', '.button_add_field', AutoAffiliateAction._appendTemplate );
            $( document ).on('click', '#affiliate-clear-logs', AutoAffiliateAction._clearLogs );
            $( document ).on('click', '.nav-tab', AutoAffiliateAction._switchWelcomeTabs );
            $( document ).ready( AutoAffiliateAction._languageLocationSelector() );


        },

        /**
         * Language and Location Selector
         *
         */
         _languageLocationSelector: function( ) {
            $('.affiliate-language-location-selector').click(function(e) {
                console.log('click selector');
                e.preventDefault();
                e.stopPropagation();
                /* api type expanded */
                $(this).toggleClass('expanded');

                /* set from language value */
                //var translator_from_language = $('#'+$(e.target).attr('for'));
                var language = $(this).find('#'+$(e.target).attr('for'));
                console.log(language);
                language.prop('checked',true);
            });
        },


        /**
         * Switch Welcome Tabs
         *
         */
        _switchWelcomeTabs: function( event ) {

            event.preventDefault();
            var tab = '#' + $(this).data('nav');

            $('.nav-tab').removeClass('nav-tab-active');
            $(this).addClass('nav-tab-active');

            $('.nav-container').removeClass('active');
            $('.affiliate-welcome-tabs').find(tab).addClass('active');

        },

        /**
         * Switch Tabs
         *
         */
        _switchTabs: function( event ) {

            event.preventDefault();

            var tab = '#' + $(this).data('nav');

            $('.affiliate-vertical-tab').removeClass('current');
            $(this).parent().addClass('current');

            $('.affiliate-box-tab').removeClass('active');
            $('.affiliate-box-tabs').find(tab).addClass('active');

        },

        /**
         * Search Suggest
         *
         */
        _searchSuggest: function( ) {

            var term = $(this).val();

            $.ajax({
                    url  : 'https://clients1.google.com/complete/search',
                    type : 'GET',
                    dataType: 'jsonp',
                    data: {
                        q: term,
                        nolabels: 't',
                        client: 'hp',
                        ds: ''
                    },
                })
                .fail(function( jqXHR ){
                    console.log( jqXHR.status + ' ' + jqXHR.responseText);
                })
                .done(function ( data ) {

                    var result = [];

                    $.each( data[1], function( key, value ) {
                        result[key] = value[0];
                    });

                    var template = wp.template('affiliate-search-results');

                    jQuery('.search-result-list').show().html(template( result ));

                });

        },

        /**
         * Select Keyword
         *
         */
        _selectKeyword: function( event ) {

            event.preventDefault();

            var keyword = $(this).data('keyword');
            var parsed = keyword.replace(/(<([^>]+)>)/ig,"");

            $('#affiliate-selected-keywords').val(function(i, text) {
                if(text.length === 0){
                    return text +  parsed;
                }else{
                    return text + ', '+ parsed;
                }
            });


        },

        /**
         * Save Campaign
         *
         */
        _saveCampaign: function( ) {

            // set post form data
            var formdata = $('.affiliate-campaign-form').serializeArray();
            var fields = {};
            $(formdata ).each(function(index, obj){
                fields[obj.name] = obj.value;
            });
            fields['campaign_status'] = 'draft';
            fields['update_frequency'] = $('.range-slider__value').text();
            fields['update_frequency_unit'] = $('#affiliate-field-unit-button').val();
            fields['affiliate_post_status'] = $('#affiliate-post-status').val();
            fields['affiliate_post_type'] = $('#affiliate-post-type').val();
            fields['affiliate_post_author'] = $('#affiliate-post-author').val();
            fields['translation'] = $('.translation.active').data('nav');
            fields['facebook_source_type'] = $('.facebook_source_type.active').data('nav');


            // set selected category data
            var select_category_data = $('.affiliate-category-multi-select').select2('data');
            var selected_category = select_category_data.map(function (el) {
                return el.id;
            });
            fields['affiliate-post-category'] = selected_category;

            // set selected tag data
            var select_tag_data = $('.affiliate-tag-multi-select').select2('data');
            var selected_tag = select_tag_data.map(function (el) {
                return el.id;
            });
            console.log(selected_tag);
            fields['affiliate-post-tag'] = selected_tag;

            $.ajax({
                    url  : Auto_Affiliate_Data.ajaxurl,
                    type : 'POST',
                    dataType: 'json',
                    data : {
                        action       : 'auto_affiliate_save_campaign',
                        fields_data  : fields,
                        _ajax_nonce  : Auto_Affiliate_Data._ajax_nonce


                    },
                    beforeSend: function() {

                        $('.affiliate-status-changes').html('<ion-icon name="reload-circle"></ion-icon></ion-icon>Saving');

                    },
                })
                .fail(function( jqXHR ){
                    console.log( jqXHR.status + ' ' + jqXHR.responseText);
                })
                .done(function ( options ) {
                    if( false === options.success ) {
                        console.log(options);
                    } else {
                        $( "input[name='campaign_id']" ).val(options.data);


                        // update campaign status
                        $('.affiliate-tag').html('draft');
                        $('.affiliate-tag').removeClass('affiliate-tag-published');
                        $('.affiliate-tag').addClass('affiliate-tag-draft');

                        // update campaign save icon status
                        $('.affiliate-status-changes').html('<ion-icon class="affiliate-icon-saved" name="checkmark-circle"></ion-icon>Saved');

                        // update campaign button text
                        $('.campaign-save-text').text('save draft');
                        $('.campaign-publish-text').text('publish');

                        //update page url with campaign id
                        var campaign_url = Auto_Affiliate_Data.wizard_url+ '&id=' + options.data + '&source=' + fields['affiliate_selected_source'];
                        window.history.replaceState('','',campaign_url);
                    }
                });

        },

        /**
         * Publish Campaign
         *
         */
        _publishCampaign: function( ) {

            var formdata = $('.affiliate-campaign-form').serializeArray();
            var fields = {};
            $(formdata ).each(function(index, obj){
                fields[obj.name] = obj.value;
            });
            fields['campaign_status'] = 'publish';
            fields['update_frequency'] = $('.range-slider__value').text();
            fields['update_frequency_unit'] = $('#affiliate-field-unit-button').val();
            fields['affiliate_post_status'] = $('#affiliate-post-status').val();
            fields['affiliate_post_type'] = $('#affiliate-post-type').val();
            fields['affiliate_post_author'] = $('#affiliate-post-author').val();
            fields['translation'] = $('.translation.active').data('nav');
            fields['facebook_source_type'] = $('.facebook_source_type.active').data('nav');


            // set selected category data
            var select_category_data = $('.affiliate-category-multi-select').select2('data');
            var selected_category = select_category_data.map(function (el) {
                return el.id;
            });
            fields['affiliate-post-category'] = selected_category;

            // set selected tag data
            var select_tag_data = $('.affiliate-tag-multi-select').select2('data');
            var selected_tag = select_tag_data.map(function (el) {
                return el.id;
            });
            console.log(selected_tag);
            fields['affiliate-post-tag'] = selected_tag;

            console.log(Auto_Affiliate_Data.ajaxurl);

            $.ajax({
                    url  : Auto_Affiliate_Data.ajaxurl,
                    type : 'POST',
                    dataType: 'json',
                    data : {
                        action       : 'auto_affiliate_save_campaign',
                        fields_data  : fields,
                        _ajax_nonce  : Auto_Affiliate_Data._ajax_nonce,


                    },
                    beforeSend: function() {

                        $('.affiliate-status-changes').html('<ion-icon name="reload-circle"></ion-icon></ion-icon>Saving');

                    },
                })
                .fail(function( jqXHR ){
                    console.log( jqXHR.status + ' ' + jqXHR.responseText);
                })
                .done(function ( options ) {
                    if( false === options.success ) {
                        console.log(options);
                    } else {
                        $( "input[name='campaign_id']" ).val(options.data);

                        // update campaign tag status
                        $('.affiliate-tag').html('published');
                        $('.affiliate-tag').removeClass('affiliate-tag-draft');
                        $('.affiliate-tag').addClass('affiliate-tag-published');

                        // update campaign save icon status
                        $('.affiliate-status-changes').html('<ion-icon class="affiliate-icon-saved" name="checkmark-circle"></ion-icon>Saved');

                        // update campaign button text
                        $('.campaign-save-text').text('unpublish');
                        $('.campaign-publish-text').text('update');

                        //update page url with campaign id
                        var campaign_url = Auto_Affiliate_Data.wizard_url+ '&id=' + options.data + '&source=' + fields['affiliate_selected_source'];
                        window.history.replaceState('','',campaign_url);
                    }
                });

        },

        /**
         * Run Campaign
         *
         */
        _runCampaign: function( ) {

            var fields = {};
            fields['campaign_id'] = $( "input[name='campaign_id']" ).val();

            $.ajax({
                    url  : Auto_Affiliate_Data.ajaxurl,
                    type : 'POST',
                    dataType: 'json',
                    data : {
                        action       : 'auto_affiliate_run_campaign',
                        fields_data  : fields,
                        _ajax_nonce  : Auto_Affiliate_Data._ajax_nonce,
                    },
                    beforeSend: function() {
                      $('.affiliate-box-footer').hide();
                      $('.affiliate-campaign-popup-body').html('<div class="affiliate-campaign-running"><div class="loader" id="loader-1"></div><span>running now...</span><div>');
                    },
                })
                .fail(function( jqXHR ){
                    console.log( jqXHR.status + ' ' + jqXHR.responseText);
                })
                .done(function ( option ) {
                    if( false === option.success ) {
                        console.log(option);
                        $('.affiliate-campaign-popup-body').html(option.data);
                    } else {
                        console.log(option.data);
                        $('.affiliate-campaign-popup-body').html('Running Log:<br>');
                        $.each(option.data, function(index, value) {
                            $('.affiliate-campaign-popup-body').append(value.message);
                            $('.affiliate-campaign-popup-body').append('<br>');
                        });
                        $('.affiliate-campaign-popup-body').append('Finished');

                        $('.affiliate-box-footer').show();
                    }

                });

        },


        /**
         * Sticky Header
         *
         */
        _stickyHeader: function( ) {

                //===== Sticky

                $(window).on('scroll',function(event) {
                    var scroll = $(window).scrollTop();
                    if (scroll < 245) {
                         $(".affiliate-box-sticky").removeClass("affiliate-is-sticky");
                    }else{
                          $(".affiliate-box-sticky").addClass("affiliate-is-sticky");
                    }
                });

        },

        /**
         * Load Popup
         *
         */
        _loadPopup: function( ) {

            $('.open-popup-campaign').magnificPopup({
                type:'inline',
                midClick: true, // Allow opening popup on middle mouse click. Always set it to true if you don't provide alternative source in href.
                // Delay in milliseconds before popup is removed
                removalDelay: 300,

                // Class that is added to popup wrapper and background
                // make it unique to apply your CSS animations just to this exact popup
                callbacks: {
                    beforeOpen: function() {
                        this.st.mainClass = this.st.el.attr('data-effect');
                    }
                },
            });

        },

        /**
         * Mobile Select
         *
         */
        _mobileSelect: function( ) {

            // onClick new options list of new select
            var newOptions = $('.affiliate-vertical-tabs > li');
            newOptions.on('click', function(){
                $('.affiliate-select-content').text($(this).text());
                $('.affiliate-vertical-tabs > li').removeClass('selected');
                $(this).addClass('selected');
            });

            var aeDropdown = $('.affiliate-sidenav');
            aeDropdown.on('click', function(){
                $('.affiliate-vertical-tabs').toggleClass('affiliate-sidenav-hide-md');
            });

        },

        /**
         * Range Slider
         *
         */
        _rangeSlider: function( ) {

            var slider = $('.range-slider'),
                range = $('.range-slider__range'),
                value = $('.range-slider__value');

            slider.each(function(){

                value.each(function(){
                    var value = $(this).prev().attr('value');
                    $(this).html(value);
                });

                range.on('input', function(){
                    $(this).next(value).html(this.value);
                });
            });

        },

        /**
         * Main Select
         *
         */
        _mainSelect: function( ) {

            // onClick new options list of new select
            var newOptions = $('.list-results > li');
            newOptions.on('click', function(){
                $(this).closest('.select-list-container').find('.list-value').text($(this).text());
                $(this).closest('.select-list-container').find('.list-value').val($(this).text());
                $(this).closest('.select-list-container').find('.list-results > li').removeClass('selected');
                $(this).addClass('selected');
            });

            var aeDropdown = $('.select-list-container');
            aeDropdown.on('click', function(){
                $(this).closest('.select-list-container').find('.list-results').toggleClass('affiliate-sidenav-hide-md');
            });

            var affiliateDropdown = $('.dropdown-handle');
            affiliateDropdown.on('click', function(){
                $(this).closest('.select-list-container').find('.list-results').toggleClass('affiliate-sidenav-hide-md');
            });

        },

        /**
         * Post Select
         *
         */
        _postSelect: function( ) {

            // onClick new options list of new select
            var newOptions = $('.post-list-results > li');
            newOptions.on('click', function(){
                $('.post-list-value').text($(this).text());
                $('.post-list-value').val($(this).text());
                $('.post-list-results > li').removeClass('selected');
                $(this).addClass('selected');
            });

            var aeDropdown = $('.post-select-list-container');
            aeDropdown.on('click', function(){
                $('.post-list-results').toggleClass('affiliate-sidenav-hide-md');
            });

            var affiliateDropdown = $('.post-dropdown-handle');
            affiliateDropdown.on('click', function(){
                $('.post-list-results').toggleClass('affiliate-sidenav-hide-md');
            });
        },

        /**
         * Type Select
         *
         */
        _typeSelect: function( ) {

            // onClick new options list of new select
            var newOptions = $('.type-list-results > li');
            newOptions.on('click', function(){
                $('.type-list-value').text($(this).text());
                $('.type-list-value').val($(this).text());
                $('.type-list-results > li').removeClass('selected');
                $(this).addClass('selected');
            });

            var aeDropdown = $('.type-select-list-container');
            aeDropdown.on('click', function(){
                $('.type-list-results').toggleClass('affiliate-sidenav-hide-md');

            });

            var affiliateDropdown = $('.type-dropdown-handle');
            affiliateDropdown.on('click', function(){
                $('.type-list-results').toggleClass('affiliate-sidenav-hide-md');
            });

        },

        /**
         * Author Select
         *
         */
        _authorSelect: function( ) {

            // onClick new options list of new select
            var newOptions = $('.author-list-results > li');
            newOptions.on('click', function(){
                $('.author-list-value').text($(this).text());
                $('.author-list-value').val($(this).text());
                $('.author-list-results > li').removeClass('selected');
                $(this).addClass('selected');
            });

            var aeDropdown = $('.author-select-list-container');
            aeDropdown.on('click', function(){
                $('.author-list-results').toggleClass('affiliate-sidenav-hide-md');

            });

            var affiliateDropdown = $('.author-dropdown-handle');
            affiliateDropdown.on('click', function(){
                $('.author-list-results').toggleClass('affiliate-sidenav-hide-md');
            });

        },

        /**
         * Category Select
         *
         */
        _categorySelect: function( ) {

            // Categories Select2
            $(".affiliate-category-multi-select").select2({
                placeholder: "Select your post categories here", //placeholder
                allowClear: true
            });

            // Tags Select2
            $(".affiliate-tag-multi-select").select2({
                placeholder: "Select your post tags here", //placeholder
                allowClear: true
            });

        },

        /**
         * Switch Sui Tabs
         *
         */
        _switchSuiTabs: function( event ) {

            event.preventDefault();

            //console.log('clicked');

            var tab = '#' + $(this).data('nav');

            console.log(tab);

            $('.sui-tab-item').removeClass('active');
            $(this).addClass('active');

            $('.sui-tab-content').removeClass('active');
            $('.sui-tabs-content').find(tab).addClass('active');


        },

        /**
         * Source Select
         *
         */
        _sourceSelect: function( ) {

            var tab = '#' + $('.affiliate_youtube_source_category').val();

            // Load action tab
            //$('.sui-tab-content').removeClass('active');
            $('.sui-tabs-content').find(tab).addClass('active');

            // onClick new options list of new select
            var newOptions = $('.source-list-results > li');
            newOptions.on('click', function(){
                $('.source-list-value').text($(this).text());
                $('.source-list-value').val($(this).text());
                $('.source-list-results > li').removeClass('selected');
                $(this).addClass('selected');
            });

            var aeDropdown = $('.source-select-list-container');
            aeDropdown.on('click', function(){
                $('.source-list-results').toggleClass('source-affiliate-sidenav-hide-md');
            });

            var affiliateDropdown = $('.source-dropdown-handle');
            affiliateDropdown.on('click', function(){
                $('.source-list-results').toggleClass('source-affiliate-sidenav-hide-md');
            });

        },

        /**
         * Source Select Tab
         *
         */
        _sourceSelectTab: function( event ) {

            event.preventDefault();

            // onClick new options list of new select
            var newOptions = $('.source-list-results > li');
            newOptions.on('click', function(){

                var tab = '#' + $(this).data('nav');


                $('.sui-tab-content').removeClass('active');
                $('.sui-tabs-content').find(tab).addClass('active');

                $('.affiliate_youtube_source_category').val($(this).text());

            });

        },

        /**
         * Append template shortcode
         *
         */
        _appendTemplate: function( ) {
            var template = $("#affiliate-main-post-template").val();
            var shortcode = $("#affiliate-field-shortcode-button").val();
            console.log(template + shortcode);
            $("#affiliate-main-post-template").val(template + shortcode);
        },

        /**
         * Clear logs
         *
         */
        _clearLogs: function( event ) {

            event.preventDefault();

            if (!confirm('Are you sure you wish to permanently delete logs?')) {
				return;
			}

            $.ajax({
                url  : Auto_Affiliate_Data.ajaxurl,
                type : 'POST',
                dataType: 'json',
                data : {
                    action       : 'auto_affiliate_clear_logs',
                    _ajax_nonce  : Auto_Affiliate_Data._ajax_nonce,
                },
                beforeSend: function() {
                },
            })
            .fail(function( jqXHR ){
                console.log( jqXHR.status + ' ' + jqXHR.responseText);
            })
            .done(function ( options ) {
                if( false === options.success ) {
                    console.log(options);
                } else {
                    AutoAffiliateAction._displayNoticeMessage(options.data);
                    window.location.reload();
                }
            });


        },

        /**
         * Display Notice Message
         *
         */
        _displayNoticeMessage: function(message) {
            var html = '<div class="message-box affiliate-message-box success">' + message + '</div>';
            $(html).appendTo(".affiliate-wrap").fadeIn('slow').animate({opacity: 1.0}, 2500).fadeOut('slow');;

        },

        /**
         * Category Selector
         *
         */
         _translatorAPISelector: function( ) {

            $('.translator-api').click(function(e) {
                e.preventDefault();
                e.stopPropagation();
                /* api type expanded */
                $(this).toggleClass('expanded');

                /* set api value */
                var translator_api = $('#'+$(e.target).attr('for'));
                translator_api.prop('checked',true);
            });

            $('.translator-from-language').click(function(e) {
                e.preventDefault();
                e.stopPropagation();
                /* api type expanded */
                $(this).toggleClass('expanded');

                /* set from language value */
                //var translator_from_language = $('#'+$(e.target).attr('for'));
                var translator_from_language = $(this).find('#'+$(e.target).attr('for'));
                translator_from_language.prop('checked',true);
            });

            $('.translator-to-language').click(function(e) {
                e.preventDefault();
                e.stopPropagation();
                /* api type expanded */
                $(this).toggleClass('expanded');

                /* set to language value */
                //var translator_to_language = $('#'+$(e.target).attr('for'));
                var translator_to_language = $(this).find('#'+$(e.target).attr('for'));
                translator_to_language.prop('checked',true);
            });

        },

    };

    /**
     * Initialize AutoAffiliateAction
     */
    $(function(){
        AutoAffiliateAction.init();
    });

})(jQuery);
