(function($){

    "use strict";

    var AutoAffiliateList = {

        init: function()
        {
            // Document ready.
            $( document ).ready( AutoAffiliateList._loadPopup() );
            $( document ).ready( AutoAffiliateList._displayDetails() );



            this._bind();
        },

        /**
         * Binds events for the Auto Affiliate List.
         *
         * @since 1.0.0
         * @access private
         * @method _bind
         */
        _bind: function()
        {
            $( document ).on('click', AutoAffiliateList._hideModal );
            $( document ).on('click', '.affiliate-dropdown-anchor', AutoAffiliateList._displayActions );
            $( document ).on('click', '.affiliate-close-popup', AutoAffiliateList._closePopup );
            $( document ).on('click', '.affiliate-delete-action', AutoAffiliateList._deleteAction );
            $( document ).on('click', '#affiliate-check-all-campaigns', AutoAffiliateList._checkAll );
            $( document ).on('click', '.affiliate-bulk-action-button', AutoAffiliateList._preparePost );

            $( document ).on('click', '.aa-popup-source-selector', AutoAffiliateList._popupTemplate );

        },

        /**
         * Popup template
         *
         */
         _popupTemplate: function( event ) {
            event.preventDefault();
            console.log('popup template');
            var modal = $('.modal');
            modal.toggleClass("show-modal");
        },

        /**
         * Hide Modal
         *
         */
         _hideModal: function( event ) {
            var modal = $('.modal');
            var closeButton = $('.auto-affiliate-close-button');
            if ($(event.target).hasClass('modal') || $(event.target).hasClass('auto-affiliate-close-button')) {
                if(modal.hasClass('show-modal')){
                    console.log('the hide modal');
                    modal.removeClass("show-modal");
                }

            }
        },

        /**
         * Display Actions
         *
         */
        _displayActions: function( event ) {

            event.preventDefault();


            if($(this).closest('.affiliate-dropdown').find('.affiliate-dropdown-list').hasClass('active')){
                $(this).closest('.affiliate-dropdown').find('.affiliate-dropdown-list').removeClass('active');
            }else{
                $(this).closest('.affiliate-dropdown').find('.affiliate-dropdown-list').addClass('active');
            }

        },

        /**
         * Load Popup
         *
         */
        _loadPopup: function( ) {

            $('.open-popup-delete').magnificPopup({
                type:'inline',
                midClick: true, // Allow opening popup on middle mouse click. Always set it to true if you don't provide alternative source in href.
                // Delay in milliseconds before popup is removed
                removalDelay: 300,

                // Class that is added to popup wrapper and background
                // make it unique to apply your CSS animations just to this exact popup
                callbacks: {
                    beforeOpen: function() {
                        this.st.mainClass = this.st.el.attr('data-effect');
                    }
                },
            });

        },

        /**
         * Close Popup
         *
         */
        _closePopup: function( ) {

            $('.open-popup-delete').magnificPopup('close');

        },

        /**
         * Delete Action
         *
         */
        _deleteAction: function( ) {

            var data = $(this).data('campaign-id');

            $('.affiliate-delete-id').val(data);


        },

        /**
         * Check All
         *
         */
        _checkAll: function( ) {

            if($(this).prop('checked')){
                $('.affiliate-check-single-campaign').prop('checked', true);
            }else{
                $('.affiliate-check-single-campaign').prop('checked', false);

            }

        },

        /**
         * Prepare data before post action
         *
         */
        _preparePost: function( ) {

            var ids = [];
            $('.affiliate-check-single-campaign').each(function( index ) {
                if($(this).prop('checked')){
                    var value = $(this).val();
                    ids.push(value);
                }
            });

            $('#affiliate-select-campaigns-ids').val(ids);

        },

        /**
         * Display Campaign Details
         *
         */
        _displayDetails: function( ) {

            var indicator = $('.affiliate-accordion-open-indicator');
            indicator.on('click', function(){
                $(this).closest('.affiliate-accordion-item').find('.affiliate-accordion-item-body').toggleClass('affiliate-campaign-detail-hide');
                $(this).closest('.affiliate-accordion-item').find('.affiliate-accordion-item-date').toggleClass('affiliate-campaign-detail-hide');
            });



        },


    };

    /**
     * Initialize AutoAffiliateList
     */
    $(function(){
        AutoAffiliateList.init();
    });

})(jQuery);
