<?php
/**
 * Auto_Affiliate Class
 *
 * Plugin Core Class
 *
 * @since  1.0.0
 * @package Auto Affiliate
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit;
} // Exit if accessed directly

if ( ! class_exists( 'Auto_Affiliate_Core' ) ) :

   class Auto_Affiliate_Core {

       /**
       * @var Auto_Affiliate_Admin
       */
       public $admin;

       /**
       * Store modules objects
       *
       * @var array
       */
       public $modules = array();

       /**
       * Store forms objects
       *
       * @var array
       */
       public $forms = array();

       /**
       * Store fields objects
       *
       * @var array
       */
       public $fields = array();

       /**
       * Plugin instance
       *
       * @var null
       */
       private static $instance = null;

       /**
       * Return the plugin instance
       *
       * @since 1.0.0
       * @return Auto_Affiliate_Core
       */
       public static function get_instance() {
        if ( is_null( self::$instance ) ) {
            self::$instance = new self();
        }

        return self::$instance;
    }

       /**
       * Auto_Affiliate_Core constructor.
       *
       * @since 1.0
       */
       public function __construct() {
           // Include all necessary files
           $this->includes();


           if ( is_admin() ) {
              // Initialize admin core
              $this->admin = new Auto_Affiliate_Admin();
           }

           // Get enabled modules
           $modules       = new Auto_Affiliate_Modules();
           $this->modules = $modules->get_modules();

           $check_auto_affiliate_wizard = get_option( 'auto-affiliate-wizard-set-up' );

           // Add integrations and logs page
           if ( is_admin() ) {
                $this->admin->add_settings_page();
                $this->admin->add_logs_page();
                $this->admin->add_welcome_page();
                $this->admin->add_import_page();
           }

       }

       /**
       * Includes
       *
       * @since 1.0.0
       */
       private function includes() {
           // Library
           if ( ! class_exists( 'simple_html_dom_node' ) ){
              require_once AUTO_AFFILIATE_DIR . 'includes/library/simple_html_dom.php';
           }

           require_once AUTO_AFFILIATE_DIR . 'includes/library/SpinRewriterAPI.php';

           // Helpers
           require_once AUTO_AFFILIATE_DIR . 'includes/helpers/helper-core.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/helpers/helper-forms.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/helpers/helper-fields.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/helpers/helper-addons.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/helpers/helper-logs.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/helpers/helper-user-data.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/helpers/helper-report.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/helpers/TextHelper.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/helpers/TemplateHelper.php';

           // Model
           require_once AUTO_AFFILIATE_DIR . 'includes/model/class-base-form-model.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/model/class-custom-form-model.php';


           // Jobs
           require_once AUTO_AFFILIATE_DIR . 'includes/jobs/abstract-class-job.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/jobs/class-parse-job.php';

           // Shop
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/class-parser-manager.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/class-shop-manager.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/ShopParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/ParserManager.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/Cpa.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/Shop.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/config.php';

           // App
           require_once AUTO_AFFILIATE_DIR . 'includes/app/Config.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/app/GeneralConfig.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/app/CookiesConfig.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/app/WpHttpClient.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/app/RestClient.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/app/GimmeproxyApi.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/app/ProxyConfig.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/app/CurlProxy.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/app/CurlProxy.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/app/FormValidator.php';

           // Cell
           require_once AUTO_AFFILIATE_DIR . 'includes/cell/Model.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/cell/AutoblogItemModel.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/cell/ProductModel.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/cell/PriceAlertModel.php';

           // Shop Parsers
        //    $shopParsersFiles = glob(AUTO_AFFILIATE_DIR . 'includes/shop/parsers/*.php');

        //    foreach ($shopParsersFiles as $file) {
        //     require($file);
        //    }

           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/EbaycomParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/ShopeevnParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/ShopeesgParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/ShopeecoidParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/ShopeecombrParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/ShopeecommyParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/LdShopParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/JumiacomegParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/JumiacokeParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/JumiacomngParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/JumiaugParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/BolcomParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/CoolbluenlParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/CoolbluebeParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/CoolbluedeParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/EbaycoukParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/EbaydeParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/EbayesParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/EbayfrParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/EbayinParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/EbayitParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/EtsyParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/FnaccomParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/KameraexpressnlParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/LdlccomParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/MaterielnetParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/WigglecomParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/WigglecoukParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/AsoscomParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/CromacomParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/MicrodataShopParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/FirstcrycomParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/FlipkartcomParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/IndustrybuyingParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/MyntracomParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/PepperfrycomParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/SnapdealParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/ShopcluesParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/CoupangcomParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/MicrodataShopParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/AllouaParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/ChiccocomuaParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/LamodauaParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/StylusuaParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/RozetkacomuaParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/AirbnbruParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/AirbnbcomParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/AlibabacomParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/BanggoodParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/BestbuycomParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/BodybuildingcomParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/GearbestcomParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/GeekbuyingcomParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/LightintheboxcomParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/NeweggcomParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/RuiherbcomParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/SuppzcomParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/TigerfitnesscomParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/TomtopcomParser.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/shop/parsers/TikivnParser.php';

           // Classes
           require_once AUTO_AFFILIATE_DIR . 'includes/class-loader.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/class-modules.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/class-log.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/class-schedule.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/class-config.php';
           require_once AUTO_AFFILIATE_DIR . 'includes/class-log-list-table.php';

           if ( is_admin() ) {
               require_once AUTO_AFFILIATE_DIR . 'admin/abstracts/class-admin-page.php';
               require_once AUTO_AFFILIATE_DIR . 'admin/abstracts/class-admin-module.php';
               require_once AUTO_AFFILIATE_DIR . 'admin/classes/class-admin.php';
           }

       }

   }

endif;
