<?php

if ( ! defined( 'ABSPATH' ) ) {
    exit;
} // Exit if accessed directly

/**
 * Return needed cap for admin pages
 *
 * @since 1.0.0
 * @return string
 */
function auto_affiliate_get_admin_cap() {
	$cap = 'manage_options';

	if ( is_multisite() && is_network_admin() ) {
		$cap = 'manage_network';
	}

	return apply_filters( 'auto_affiliate_admin_cap', $cap );
}

/**
 * Enqueue admin fonts
 *
 * @since 1.0.0
 * @since 1.5.1 implement $version
 *
 * @param $version
 */
function auto_affiliate_admin_enqueue_fonts( $version ) {
	wp_enqueue_style(
		'auto_affiliate-affiliateo',
		'https://fonts.googleapis.com/css?family=Affiliateo+Condensed:300,300i,400,400i,700,700i|Affiliateo:300,300i,400,400i,500,500i,700,700i',
		array(),
		'1.0.0'
	); // cache as long as you can
	wp_enqueue_style(
		'auto_affiliate-opensans',
		'https://fonts.googleapis.com/css?family=Open+Sans:400,400i,700,700i',
		array(),
		'1.0.0'
	); // cache as long as you can
	wp_enqueue_style(
		'auto_affiliate-source',
		'https://fonts.googleapis.com/css?family=Source+Code+Pro',
		array(),
		'1.0.0'
	); // cache as long as you can

	// if plugin internal font need to enqueued, please use $version as its subject to cache
}

/**
 * Enqueue admin styles
 *
 * @since 1.0.0
 * @since 1.1 Remove auto_affiliate-admin css after migrate to shared-ui
 *
 * @param $version
 */
function auto_affiliate_admin_enqueue_styles( $version ) {
	wp_enqueue_style( 'magnific-popup', AUTO_AFFILIATE_URL . 'assets/css/magnific-popup.css', array(), $version, false );
    wp_enqueue_style( 'auto-affiliate-select2-style', AUTO_AFFILIATE_URL . 'assets/css/select2.min.css', array(), $version, false );
    wp_enqueue_style( 'auto-affiliate-main-style', AUTO_AFFILIATE_URL . 'assets/css/main.css', array(), $version, false );
}


/**
 * Load admin scripts
 *
 * @since 1.0.0
 */
function auto_affiliate_admin_jquery_ui_init() {
	wp_enqueue_script( 'jquery-ui-core' );
	wp_enqueue_script( 'jquery-ui-widget' );
	wp_enqueue_script( 'jquery-ui-mouse' );
	wp_enqueue_script( 'jquery-ui-tabs' );
	wp_enqueue_script( 'jquery-ui-sortable' );
	wp_enqueue_script( 'jquery-ui-draggable' );
	wp_enqueue_script( 'jquery-ui-droppable' );
	wp_enqueue_script( 'jquery-ui-datepicker' );
	wp_enqueue_script( 'jquery-ui-resize' );
	wp_enqueue_style( 'wp-color-picker' );
}

/**
 * Enqueue admin welcome scripts
 *
 * @since 1.0.0
 *
 * @param       $version
 * @param array $data
 * @param array $l10n
 */
function auto_affiliate_admin_enqueue_scripts_welcome( $version, $data = array(), $l10n = array() ) {
    wp_enqueue_script( 'ionicons', 'https://unpkg.com/ionicons@5.0.0/dist/ionicons.js', array(), $version, false );

    wp_register_script(
		'auto-affiliate-welcome',
		AUTO_AFFILIATE_URL . '/assets/js/welcome.js',
        array( 'jquery', 'wp-util' ),
		$version,
		true
	);

    wp_register_script(
		'auto-affiliate-snap',
		AUTO_AFFILIATE_URL . '/assets/js/library/snap.svg-min.js',
		array(),
		$version,
		true
	);

    wp_enqueue_script( 'auto-affiliate-snap' );
    wp_enqueue_script( 'auto-affiliate-welcome' );
    wp_localize_script( 'auto-affiliate-welcome', 'Auto_Affiliate_Data', $data );
}

/**
 * Enqueue admin import scripts
 *
 * @since 1.0.0
 *
 * @param       $version
 * @param array $data
 * @param array $l10n
 */
function auto_affiliate_admin_enqueue_scripts_import( $version, $data = array(), $l10n = array() ) {
    wp_enqueue_script( 'ionicons', 'https://unpkg.com/ionicons@5.0.0/dist/ionicons.js', array(), $version, false );

    wp_register_script(
		'auto-affiliate-import',
		AUTO_AFFILIATE_URL . '/assets/js/import.js',
        array( 'jquery', 'wp-util' ),
		$version,
		true
	);

    wp_enqueue_script( 'auto-affiliate-import' );
    wp_localize_script( 'auto-affiliate-import', 'Auto_Affiliate_Data', $data );
}

/**
 * Enqueue admin scripts
 *
 * @since 1.0.0
 *
 * @param       $version
 * @param array $data
 * @param array $l10n
 */
function auto_affiliate_admin_enqueue_scripts( $version, $data = array(), $l10n = array() ) {

    if ( function_exists( 'wp_enqueue_editor' ) ) {
        wp_enqueue_editor();
    }
    if ( function_exists( 'wp_enqueue_media' ) ) {
        wp_enqueue_media();
    }

	wp_enqueue_script( 'ionicons', 'https://unpkg.com/ionicons@5.0.0/dist/ionicons.js', array(), $version, false );

	wp_enqueue_script( 'jquery-magnific-popup', AUTO_AFFILIATE_URL . '/assets/js/library/jquery.magnific-popup.min.js', array( 'jquery' ), $version, false );

	wp_enqueue_script( 'auto-affiliate-chart', AUTO_AFFILIATE_URL  . '/assets/js/library/Chart.bundle.min.js', array( 'jquery' ), '1.0.0', false );

    wp_enqueue_script( 'auto-affiliate-select2', AUTO_AFFILIATE_URL . '/assets/js/library/select2.min.js', array( 'jquery' ), $version, false );


    wp_register_script(
        'auto-affiliate-admin',
        AUTO_AFFILIATE_URL . '/assets/js/main.js',
        array(
            'jquery'
        ),
        $version,
        true
    );
	wp_register_script(
		'auto-affiliate-action',
		AUTO_AFFILIATE_URL . '/assets/js/action.js',
		array(
			'jquery'
		),
		$version,
		true
	);
    wp_register_script(
		'auto-affiliate-list',
		AUTO_AFFILIATE_URL . '/assets/js/list.js',
		array(
			'jquery'
		),
		$version,
		true
	);
	wp_register_script(
		'auto-affiliate-addon',
		AUTO_AFFILIATE_URL . '/assets/js/addon.js',
		array(
			'jquery'
		),
		$version,
		true
	);
    wp_register_script(
        'auto-affiliate-settings',
        AUTO_AFFILIATE_URL . '/assets/js/settings.js',
        array(
            'jquery'
        ),
        $version,
        true
    );

    wp_enqueue_script( 'auto-affiliate-admin' );
    wp_enqueue_script( 'auto-affiliate-action' );
    wp_enqueue_script( 'auto-affiliate-list' );
	wp_enqueue_script( 'auto-affiliate-addon' );
    wp_enqueue_script( 'auto-affiliate-settings' );

    wp_localize_script( 'auto-affiliate-action', 'Auto_Affiliate_Data', $data );
}

/**
 * Enqueue admin wizard scripts
 *
 * @since 1.0.0
 *
 * @param       $version
 * @param array $data
 * @param array $l10n
 */
function auto_affiliate_admin_enqueue_scripts_wizard( $version, $data = array(), $l10n = array() ) {
    wp_enqueue_script( 'ionicons', 'https://unpkg.com/ionicons@5.0.0/dist/ionicons.js', array(), $version, false );

    wp_register_script(
		'auto-affiliate-wizard',
		AUTO_AFFILIATE_URL . '/assets/js/wizard.js',
		array(
			'jquery'
		),
		$version,
		true
	);

    wp_enqueue_script( 'auto-affiliate-wizard' );

    wp_localize_script( 'auto-affiliate-wizard', 'Auto_Affiliate_Data', $data );
}

/**
 * Enqueue admin license scripts
 *
 * @since 1.0.0
 *
 * @param       $version
 * @param array $data
 * @param array $l10n
 */
function auto_affiliate_admin_enqueue_scripts_license( $version, $data = array(), $l10n = array() ) {
    wp_enqueue_script( 'ionicons', 'https://unpkg.com/ionicons@5.0.0/dist/ionicons.js', array(), $version, false );

    wp_register_script(
		'auto-affiliate-license',
		AUTO_AFFILIATE_URL . '/assets/js/license.js',
		array(
			'jquery'
		),
		$version,
		true
	);

    wp_enqueue_script( 'auto-affiliate-license' );

    wp_localize_script( 'auto-affiliate-license', 'Auto_Affiliate_Data', $data );
}

/**
 * Return AJAX url
 *
 * @since 1.0.0
 * @return mixed
 */
function auto_affiliate_ajax_url() {
    return admin_url( 'admin-ajax.php', is_ssl() ? 'https' : 'http' );
}

/**
 * Return post status
 *
 * @since 1.0.0
 * @return array
 */
function auto_affiliate_get_post_status() {
    return apply_filters(
        'auto_affiliate_post_status',
        array(
            'publish'     => esc_html__( 'Publish',Auto_Affiliate::DOMAIN ),
            'draft'     => esc_html__( 'Draft',Auto_Affiliate::DOMAIN ),
        )
    );
}

/**
 * Return Components
 *
 * @since 1.0.0
 * @return array
 */
function auto_affiliate_get_components($source) {

    $components_dir = "campaigns/wizard/components/";

    $components = array();

    switch ( $source ) {
        case 'rss':
            $components = ['campaign-name', 'feed-links', 'content-options'];
            break;
        case 'facebook':
            $components = ['campaign-name', 'facebook-links'];
            break;
        case 'instagram':
            $components = ['campaign-name', 'instagram-source'];
            break;
        case 'youtube':
            $components = ['campaign-name', 'youtube-source'];
            break;
        case 'search':
            $components = ['campaign-name', 'language-location', 'feed-keywords'];
            break;
        default:
            $components = ['campaign-name', 'catalog-url'];
            break;
    }

    foreach($components as $key => $value){
        $components[$key] = $components_dir.$value;
    }

    return $components;
}

/**
 * Process Twitter Campaign Job
 * @param string
 * @since 1.0.0
 * @return array
 */
function auto_affiliate_get_random($keywords) {
    $keywords_array = explode(', ', $keywords);
    $rand = array_rand($keywords_array);

    return $keywords_array[$rand];
}

/**
 * Process Campaign Fetch Job
 *
 * @since 1.0.0
 * @return array
 */
function auto_affiliate_process_fetch_job($id, $catalog_url, $settings){
    // Initial job class and run this job
    $job = new Auto_Affiliate_Parse_Job( $id, $catalog_url, $settings);
    $result = $job->run();

    // Return this job running result
    return $result;
}

/**
 * Process RSS Campaign Job
 *
 * @since 1.0.0
 * @return int
 */
function auto_affiliate_calculate_next_time($update_frequency, $update_frequency_unit){
    $time_length = 0;

    switch ( $update_frequency_unit ) {
        case 'Minutes':
            $time_length = $update_frequency*60;
            break;
        case 'Hours':
            $time_length = $update_frequency*60*60;
            break;
        case 'Days':
            $time_length = $update_frequency*60*60*24;
            break;
        default:
            break;
    }

    return $time_length;
}

/**
 * Save remote image to wp upload directory
 */
function auto_affiliate_upload_image($remote_url, $filename){
    $image = wp_remote_get( $remote_url );
    $upload_dir = wp_upload_dir ();

    if (wp_mkdir_p ( $upload_dir ['path'] )){
        $file = $upload_dir ['path'] . '/' . $filename;
    }else{
        $file = $upload_dir ['basedir'] . '/' . $filename;
    }

	// check if same image name already exists
	if (file_exists ( $file )) {
		$filename = time () . '_' . rand ( 0, 999 ) . '_' . $filename;
		if (wp_mkdir_p ( $upload_dir ['path'] ))
			$file = $upload_dir ['path'] . '/' . $filename;
		else
		    $file = $upload_dir ['basedir'] . '/' . $filename;
	}

	file_put_contents ( $file, $image['body'] );
	$file_link = $upload_dir ['url'] . '/' . $filename;
    $guid = $upload_dir ['url'] . '/' . basename ( $filename );

    auto_affiliate_save_image_to_media($guid, $filename, $file);

    return $file_link;
}

/**
 * Add image to media library and attach to the post
 */
function auto_affiliate_save_image_to_media($guid, $filename, $file){
        // atttatchment check if exists or not
        global $wpdb;

        $query = "select * from $wpdb->posts where guid = '$guid' limit 1";
        $already_saved_attachment = $wpdb->get_row ( $query );

        if (isset ( $already_saved_attachment->ID )) {
            $attach_id = $already_saved_attachment->ID;
        } else {
            $wp_filetype = wp_check_filetype ( $filename, null );

            if ($wp_filetype ['type'] == false) {
                $wp_filetype ['type'] = 'image/jpeg';
            }

            // Title handling
            $imgTitle = sanitize_file_name ( $filename );

            $attachment = array (
                    'guid' => $guid,
                    'post_mime_type' => $wp_filetype ['type'],
                    'post_title' => $imgTitle,
                    'post_content' => '',
                    'post_status' => 'inherit'
            );

            $attach_id = wp_insert_attachment ( $attachment, $file);
			$attach_data = wp_generate_attachment_metadata ( $attach_id, $file );
			wp_update_attachment_metadata ( $attach_id, $attach_data );
        }

}

/*
* Checks for a new version of Auto Affiliate and creates messages if needed
*/
function auto_affiliate_check_for_newer() {
    $ret = false;
    $latest_version = '';
	$url                                  = WPHOBBY_STATS_URL . '/index.php?rest_route=/wphobby/v1/user/version';
	$response                             = wp_safe_remote_post(
		$url, array(
			'method'      => 'GET',
			'timeout'     => 10,
			'redirection' => 10,
			'httpversion' => '1.0',
			'blocking'    => true,
			'headers'     => array(),
			)
		);

	if ( ! is_wp_error( $response ) ) {
		$result = json_decode($response['body']);
        $latest_version = $result->data;
	}

	if ( !empty( $latest_version ) ) {
		$old = AUTO_AFFILIATE_VERSION;
		if ( 1 === version_compare( $latest_version, $old ) ) { // current version is lower than latest
			$msg = sprintf( __( 'A new version of %s is available. Please install it.', Auto_Affiliate::DOMAIN ), 'Auto Affiliate' );
			$ret = array( 'msg' => $msg, 'ver' => $latest_version );
		}
	}

	return $ret;
}

function auto_affiliate_currencies()
    {
        return array(
            'USD' => array(
                'currency_symbol' => '$',
                'currency_pos' => 'left',
                'thousand_sep' => ',',
                'decimal_sep' => '.',
                'num_decimals' => 2,
            ),
            'EUR' => array(
                'currency_symbol' => '&euro;',
                'currency_pos' => array(
                    'nl' => 'left',
                    'be' => 'left',
                    'de' => 'left',
                    'es' => 'right',
                    'fr' => 'right',
                    'it' => 'right',
                ),
                'thousand_sep' => '.',
                'decimal_sep' => ',',
                'num_decimals' => 2,
            ),
            'CAD' => array(
                'currency_symbol' => 'C $',
                'currency_pos' => 'left',
                'thousand_sep' => ',',
                'decimal_sep' => '.',
                'num_decimals' => 2,
            ),
            'GBP' => array(
                'currency_symbol' => '&pound;',
                'currency_pos' => 'left',
                'thousand_sep' => ',',
                'decimal_sep' => '.',
                'num_decimals' => 2,
            ),
            'JPY' => array(
                'currency_symbol' => '&yen;',
                'currency_pos' => 'left',
                'thousand_sep' => ',',
                'decimal_sep' => '.',
                'num_decimals' => 2,
            ),
            'CNY' => array(
                'currency_symbol' => '&yen;',
                'currency_pos' => 'left',
                'thousand_sep' => ',',
                'decimal_sep' => '.',
                'num_decimals' => 2,
            ),
            'RUB' => array(
                'currency_symbol' => 'руб.',
                'currency_pos' => 'right_space',
                'thousand_sep' => ' ',
                'decimal_sep' => ',',
                'num_decimals' => 0,
            ),
            'RUR' => array(
                'currency_symbol' => 'руб.',
                'currency_pos' => 'right_space',
                'thousand_sep' => ' ',
                'decimal_sep' => ',',
                'num_decimals' => 0,
            ),
            'UAH' => array(
                'currency_symbol' => 'грн.',
                'currency_pos' => 'right_space',
                'thousand_sep' => ' ',
                'decimal_sep' => ',',
                'num_decimals' => 0,
            ),
            'INR' => array(
                'currency_symbol' => 'Rs.',
                'currency_pos' => 'left_space',
                'thousand_sep' => ',',
                'decimal_sep' => '.',
                'num_decimals' => 0,
            ),
            'AUD' => array(
                'currency_symbol' => 'AU $',
                'currency_pos' => 'left',
                'thousand_sep' => ',',
                'decimal_sep' => '.',
                'num_decimals' => 2,
            ),
            'VND' => array(
                'currency_symbol' => '&#8363;',
                'currency_pos' => 'right',
                'thousand_sep' => '.',
                'decimal_sep' => ',',
                'num_decimals' => 0,
            ),
            'BRL' => array(
                'currency_symbol' => 'R$',
                'currency_pos' => 'left',
                'thousand_sep' => '.',
                'decimal_sep' => ',',
                'num_decimals' => 2,
                'name' => 'Brazilian real',
            ),
            'TND' => array(
                'currency_symbol' => 'DT',
                'currency_pos' => 'right',
                'thousand_sep' => ' ',
                'decimal_sep' => '.',
                'num_decimals' => 3,
                'name' => 'Tunisian dinar',
            ),
            'NGN' => array(
                'currency_symbol' => '₦',
                'currency_pos' => 'left',
                'thousand_sep' => ',',
                'decimal_sep' => '.',
                'num_decimals' => 2,
                'name' => 'Nigerian naira',
            ),
            'MXN' => array(
                'currency_symbol' => '$',
                'currency_pos' => 'left',
                'thousand_sep' => ',',
                'decimal_sep' => '.',
                'num_decimals' => 2,
                'name' => 'Mexican peso',
            ),
            'MDL' => array(
                'currency_symbol' => 'lei',
                'currency_pos' => 'right_space',
                'thousand_sep' => ',',
                'decimal_sep' => '.',
                'num_decimals' => 2,
                'name' => 'Moldovan leu',
            ),
            'KRW' => array(
                'currency_symbol' => '₩',
                'currency_pos' => 'left',
                'thousand_sep' => ',',
                'decimal_sep' => '.',
                'num_decimals' => 0,
                'name' => 'South Korean won',
            ),
            'THB' => array(
                'currency_symbol' => '฿',
                'currency_pos' => 'left',
                'thousand_sep' => ',',
                'decimal_sep' => '.',
                'num_decimals' => 0,
                'name' => 'Thai baht',
            ),
            'RON' => array(
                'currency_symbol' => 'Lei',
                'currency_pos' => 'right_space',
                'thousand_sep' => '.',
                'decimal_sep' => ',',
                'num_decimals' => 2,
                'name' => 'Romanian Leu',
            ),
            'EGP' => array(
                'currency_symbol' => 'جنيه',
                'currency_pos' => 'left_space',
                'thousand_sep' => ',',
                'decimal_sep' => '.',
                'num_decimals' => 2,
                'name' => 'Egypt Pound',
            ),
            'KWD' => array(
                'currency_symbol' => 'KD',
                'currency_pos' => 'right_space',
                'thousand_sep' => ',',
                'decimal_sep' => '.',
                'num_decimals' => 3,
                'name' => 'Kuwaiti dinar',
            ),
            'TRY' => array(
                'currency_symbol' => 'TL',
                'currency_pos' => 'right_space',
                'thousand_sep' => ',',
                'decimal_sep' => '.',
                'num_decimals' => 2,
                'name' => 'Turkish Lira',
            ),
            'IDR' => array(
                'currency_symbol' => 'Rp',
                'currency_pos' => 'left_space',
                'thousand_sep' => '.',
                'decimal_sep' => ',',
                'num_decimals' => 0,
                'name' => 'Indonesian Rupiah',
            ),
            'PKR' => array(
                'currency_symbol' => 'PKR.',
                'currency_pos' => 'left',
                'thousand_sep' => ',',
                'decimal_sep' => '.',
                'num_decimals' => 0,
                'name' => 'Pakistani Rupee',
            ),
            'HKD' => array(
                'currency_symbol' => 'HKD$',
                'currency_pos' => 'left',
                'thousand_sep' => ',',
                'decimal_sep' => '.',
                'num_decimals' => 2,
                'name' => 'Hong Kong dollar',
            ),
            'ILS' => array(
                'currency_symbol' => '&#8362;',
                'currency_pos' => 'left',
                'thousand_sep' => ',',
                'decimal_sep' => '.',
                'num_decimals' => 2,
                'name' => 'Israeli Shekel',
            ),
            'AED' => array(
                'currency_symbol' => 'AED',
                'currency_pos' => 'right_space',
                'thousand_sep' => ',',
                'decimal_sep' => '.',
                'num_decimals' => 2,
                'name' => 'UAE Dirham',
            ),
            'SAR' => array(
                'currency_symbol' => 'SAR',
                'currency_pos' => 'right_space',
                'thousand_sep' => ',',
                'decimal_sep' => '.',
                'num_decimals' => 2,
                'name' => 'Saudi Riyal',
            ),
            'SGD' => array(
                'currency_symbol' => '$',
                'currency_pos' => 'left',
                'thousand_sep' => ',',
                'decimal_sep' => '.',
                'num_decimals' => 2,
                'name' => 'Singapore dollar',
            ),
            'HUF' => array(
                'currency_symbol' => 'Ft',
                'currency_pos' => 'right_space',
                'thousand_sep' => '.',
                'decimal_sep' => ',',
                'num_decimals' => 0,
                'name' => 'Hungarian forint',
            ),
            'PLN' => array(
                'currency_symbol' => 'zł',
                'currency_pos' => 'right_space',
                'thousand_sep' => '',
                'decimal_sep' => ',',
                'num_decimals' => 2,
                'name' => 'Polish Zloty',
            ),
            'CZK' => array(
                'currency_symbol' => 'Kč',
                'currency_pos' => 'right_space',
                'thousand_sep' => ' ',
                'decimal_sep' => ',',
                'num_decimals' => 0,
                'name' => 'Czech koruna',
            ),
            'MYR' => array(
                'currency_symbol' => 'RM',
                'currency_pos' => 'left',
                'thousand_sep' => ',',
                'decimal_sep' => '.',
                'num_decimals' => 2,
                'name' => 'Malaysia Ringgit',
            ),
            'PCT' => array(
                'currency_symbol' => '%',
                'currency_pos' => 'right',
                'thousand_sep' => '',
                'decimal_sep' => '.',
                'num_decimals' => 1,
                'name' => 'Percentage',
            ),
            'CLP' => array(
                'currency_symbol' => '$',
                'currency_pos' => 'left',
                'thousand_sep' => '.',
                'decimal_sep' => ',',
                'num_decimals' => 0,
                'name' => 'Peso Chileno',
            ),
            'DKK' => array(
                'currency_symbol' => 'DKK',
                'currency_pos' => 'left_space',
                'thousand_sep' => '.',
                'decimal_sep' => ',',
                'num_decimals' => 2,
                'name' => 'Danske Kroner',
            ),
            'KES' => array(
                'currency_symbol' => 'KSh',
                'currency_pos' => 'left_space',
                'thousand_sep' => ',',
                'decimal_sep' => '.',
                'num_decimals' => 2,
                'name' => 'Kenyan Shilling',
            ),
            'HRK' => array(
                'currency_symbol' => 'kn',
                'currency_pos' => 'right_space',
                'thousand_sep' => '.',
                'decimal_sep' => ',',
                'num_decimals' => 2,
                'name' => 'Croatian Kuna',
            ),
            'PEN' => array(
                'currency_symbol' => 'S/',
                'currency_pos' => 'left',
                'thousand_sep' => ',',
                'decimal_sep' => '.',
                'num_decimals' => 2,
                'name' => 'Peruvian sol',
            ),
            'DOP' => array(
                'currency_symbol' => 'RD$',
                'currency_pos' => 'left',
                'thousand_sep' => ',',
                'decimal_sep' => '.',
                'num_decimals' => 2,
                'name' => 'Dominican Peso',
            ),
            'UYU' => array(
                'currency_symbol' => 'U$S',
                'currency_pos' => 'left',
                'thousand_sep' => '.',
                'decimal_sep' => ',',
                'num_decimals' => 2,
                'name' => 'Uruguayan Peso',
            ),
            'NIO' => array(
                'currency_symbol' => 'C$',
                'currency_pos' => 'left',
                'thousand_sep' => ',',
                'decimal_sep' => '.',
                'num_decimals' => 2,
                'name' => 'Nicaraguan Córdoba',
            ),
            'PAB' => array(
                'currency_symbol' => 'B/.',
                'currency_pos' => 'left',
                'thousand_sep' => '.',
                'decimal_sep' => ',',
                'num_decimals' => 2,
                'name' => 'Panamanian Balboa',
            ),
            'SVC' => array(
                'currency_symbol' => '$',
                'currency_pos' => 'left',
                'thousand_sep' => ',',
                'decimal_sep' => '.',
                'num_decimals' => 2,
                'name' => 'Salvadoran Colón',
            ),
            'GTQ' => array(
                'currency_symbol' => 'Q',
                'currency_pos' => 'left',
                'thousand_sep' => ',',
                'decimal_sep' => '.',
                'num_decimals' => 2,
                'name' => 'Guatemalan Quetzal',
            ),
            'HNL' => array(
                'currency_symbol' => 'L',
                'currency_pos' => 'left',
                'thousand_sep' => ',',
                'decimal_sep' => '.',
                'num_decimals' => 2,
                'name' => 'Honduran Lempira',
            ),
            'JMD' => array(
                'currency_symbol' => 'JM$',
                'currency_pos' => 'left',
                'thousand_sep' => ',',
                'decimal_sep' => '.',
                'num_decimals' => 2,
                'name' => 'Jamaican Dollar',
            ),
            'CRC' => array(
                'currency_symbol' => '₡',
                'currency_pos' => 'left',
                'thousand_sep' => ',',
                'decimal_sep' => '.',
                'num_decimals' => 2,
                'name' => 'Costa Rican Colón',
            ),
            'ARS' => array(
                'currency_symbol' => '$',
                'currency_pos' => 'left',
                'thousand_sep' => '.',
                'decimal_sep' => ',',
                'num_decimals' => 2,
                'name' => 'Argentine Peso',
            ),
            'BOB' => array(
                'currency_symbol' => 'Bs',
                'currency_pos' => 'left',
                'thousand_sep' => '.',
                'decimal_sep' => ',',
                'num_decimals' => 2,
                'name' => 'Bolivian Boliviano',
            ),
            'COP' => array(
                'currency_symbol' => '$',
                'currency_pos' => 'left',
                'thousand_sep' => '.',
                'decimal_sep' => ',',
                'num_decimals' => 2,
                'name' => 'Colombian Peso',
            ),
            'XOF' => array(
                'currency_symbol' => 'FCFA',
                'currency_pos' => 'left_space',
                'thousand_sep' => ',',
                'decimal_sep' => '.',
                'num_decimals' => 0,
                'name' => 'CFA Franc',
            ),
        );
    }

function auto_affiliate_deeplink_formart($url, $original_url){
    $settings = get_option('auto_affiliate_global_settings');
    $parse = parse_url($url);
    $link = str_ireplace('www.', '', $parse['host']);
    $bodytag = 'affiliate-'.str_replace(".", "_", $link).'-deeplink';
    $url_replace = isset($settings[$bodytag]) ? $settings[$bodytag] : $original_url;
    return $url_replace;
}

function auto_affiliate_deeplink_parse($url, $formart){
    if(strpos($formart, '{{url}}') !== false){
        $bodytag = str_replace("{{url}}", $url, $formart);
        return $bodytag;
    }else if(strpos($formart, '{{url_encoded}}') !== false){
        $bodytag = str_replace("{{url_encoded}}", urlencode($url), $formart);
        return $bodytag;
    }else{
        return $url;
    }
}