<?php
/**
 * Auto_Affiliate_Parse_Job Class
 *
 * @since  1.0.0
 * @package Auto Affiliate
 */


if ( ! defined( 'ABSPATH' ) ) {
    exit;
} // Exit if accessed directly

if ( ! class_exists( 'Auto_Affiliate_Parse_Job' ) ) :

    class Auto_Affiliate_Parse_Job extends Auto_Affiliate_Job{

        /**
         * Feed Link
         *
         * @var string
         */
        public $catalog_url = '';

        /**
         * Auto_Affiliate_Parse_Job constructor.
         *
         * @since 1.0.0
         */
        public function __construct($id, $catalog_url, $settings) {
            $this->id = $id;
            $this->catalog_url = $catalog_url;
            $this->settings = $settings;
            $this->logger = new Auto_Affiliate_Log($id);
        }

        /**
         * Run this job
         *
         * @return array
         */
        public function run(){
            $this->log[] = array(
                'message'   => 'Start process feed: <a href="'.$this->catalog_url.'">'.$this->catalog_url.'</a>',
                'level'     => 'log'
            );

            $items_per_check = 100;

            // 1. Parse catalog
            $error = '';
            try
            {
                $product_urls = Parser_Manager::getInstance()->parseCatalog($this->catalog_url, $items_per_check);
            } catch (\Exception $e)
            {
                $error = $e->getMessage();
            }
            if(is_null($product_urls)){
                $this->log[] = array(
                    'message'   => 'Parse job return null product urls.',
                    'level'     => 'log'
                );
                return $this->log;
            }
            $rand = rand(0, count($product_urls)-1);
            $currentURL = $product_urls[$rand];
            if(is_null($currentURL)){
                $this->log[] = array(
                    'message'   => 'Parse job return null single product url.',
                    'level'     => 'log'
                );
                return $this->log;
            }
            // 2. Create Product
            $currentProduct = ProductModel::model()->createProduct($currentURL);
            if(is_null($currentProduct) || $currentProduct === false){
                $this->log[] = array(
                    'message'   => 'Parse job return null single product data.',
                    'level'     => 'log'
                );
                return $this->log;
            }
            // 3. Insert Product into Post
            $post_title = $currentProduct['title'];
            $post_content = $this->buildProduct($currentProduct);
            $post_status = $this->settings['affiliate_post_status'];
            $post_type = $this->settings['affiliate_post_type'];
            $post_author = get_user_by('login',$this->settings['affiliate_post_author']);


            $post = array(
                'ID' => null,
                'post_title' => $post_title,
                'post_content' => $post_content,
                'post_status' => $post_status,
                'post_type' => $post_type,
                'post_author' => $post_author->ID
            );

            if(!empty($this->settings['affiliate-post-category'])){
                $post['post_category'] = $this->settings['affiliate-post-category'];
            }

            if(!empty($this->settings['affiliate-post-tag'])){
                // get tags name
                $tags = array();
                $tag_ids = $this->settings['affiliate-post-tag'];

                foreach($tag_ids as $tag_id){
                    $tag = get_tag($tag_id);
                    $tags[] = $tag->name;
                }

                $post['tags_input'] = array_values( $tags );
            }

            $post_id = \wp_insert_post($post);

            if (!$post_id) {
                $this->log[] = array(
                    'message' => 'Generate New Post Error: post-fail',
                    'level'     => 'error'
                );
            }else{
                $permalink = get_permalink( $post_id );
                $this->log[] = array(
                    'message' => 'Post New Post Success: <a href="'.$permalink.'">'.$post_title.'</a>',
                    'level'     => 'success'
                );
                // Set post feature image
                if($this->settings['affiliate_feature_image'] == 'on'){
                    $this->set_post_feature_image($post_id, $currentProduct['orig_img']);
                }
            }

            return $this->log;

        }

        /**
         * Build product section from template
         */
        private function buildProduct($args)
        {
            $file    = AUTO_AFFILIATE_DIR . "/admin/views/product/single.php";
            $content = '';

            if ( is_file( $file ) ) {
                ob_start();

                $product = $args;

                include $file;

                $content = ob_get_clean();
            }
            return $content;
        }

}

endif;
