<?php
/**
 * Auto_Affiliate_Base_Form_Model Class
 *
 * @since  1.0.0
 * @package Auto Affiliate
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly

if ( ! class_exists( 'Auto_Affiliate_Custom_Form_Model' ) ) :

    class Auto_Affiliate_Custom_Form_Model extends Auto_Affiliate_Base_Form_Model {

        protected $post_type = 'auto_affiliate_forms';

        /**
         * @param int|string $class_name
         *
         * @since 1.0
         * @return Auto_Affiliate_Custom_Form_Model
         */
        public static function model( $class_name = __CLASS__ ) { // phpcs:ignore
            return parent::model( $class_name );
        }

        /**
         * Run Campaign
         *
         * @since 1.0.0
         *
         */
        public function run_campaign() {

            $settings = $this->get_settings();

			$id = $this->id;

            //Get Catalog URL
            $catalog_url = '';
            if(isset($settings['affiliate_catalog_url'])){
               $catalog_url = $settings['affiliate_catalog_url'];
            }

            // Update Campaign Last and Next Run Time
            if ( !is_null( $id ) || $id > 0 ) {
                $form_model = Auto_Affiliate_Custom_Form_Model::model()->load( $id );
                $settings = $form_model->settings;

                // Update next run time
                $time_length = auto_affiliate_calculate_next_time($settings['update_frequency'], $settings['update_frequency_unit']);
                $settings['next_run_time'] = time() + $time_length;

                // Update last run time
                $settings['last_run_time'] = time();

                // Save Settings to model
                $form_model->settings = $settings;
                // Save data
                $id = $form_model->save();

                $logger = new Auto_Affiliate_Log($id);
                $logger->add( "Update Campaign Next Run Time \t\t: " . $settings['next_run_time']. "for campaign id ". $id, 'info'  );
            }

            $result = array();
            $result = auto_affiliate_process_fetch_job($id, $catalog_url, $settings);

            return $result;
        }
    }

endif;
